@@ -41,6 +41,7 @@ class DFSequence(tf.keras.utils.Sequence):
             input_column=INPUT_COL,
             target_column=TARGET_COL,
             target_resolution=None,
+            sample_weight_column=None,
             group_column=None,
             has_windows=False,
             window_index_column=WINDOW_INDEX_COL,
@@ -70,6 +71,7 @@ class DFSequence(tf.keras.utils.Sequence):
         self._set_columns(
             input_column,
             target_column,
+            sample_weight_column,
             group_column,
             has_windows,
             window_index_column,
@@ -134,7 +136,10 @@ class DFSequence(tf.keras.utils.Sequence):
             targ=to_categorical(targ,num_classes=self.nb_classes)
             if self.droplast:
                 targ=targ[:,:,:-1]
-        return inpt, targ
+        if self.sample_weight_column:
+            return inpt, targ, self.row[self.sample_weight_column]
+        else:
+            return inpt, targ
 
 
     def get_batch(self,batch_index,set_window=True,set_augment=True):
@@ -162,7 +167,11 @@ class DFSequence(tf.keras.utils.Sequence):
             targs=to_categorical(targs,num_classes=self.nb_classes)
             if self.droplast:
                 targs=targs[:,:,:,:-1]
-        return inpts, targs
+        if self.sample_weight_column:
+            sample_weights=np.array([r[self.sample_weight_column] for r in self.batch_rows])
+            return inpts, targs, sample_weights
+        else:
+            return inpts, targs
 
     
     def get_input(self,row=None):
@@ -222,12 +231,14 @@ class DFSequence(tf.keras.utils.Sequence):
     def _set_columns(self,
             input_column,
             target_column,
+            sample_weight_column,
             group_column,
             has_windows,
             window_index_column,
             window_column):
         self.input_column=input_column
         self.target_column=target_column
+        self.sample_weight_column=sample_weight_column
         self.has_windows=has_windows
         self.window_index_column=window_index_column
         self.window_column=window_column
